@@ -4,7 +4,7 @@ from settings import settings
 from os import path
 from os.path import expanduser
 from shutil import copyfile
-from utils import hiss
+from utils import hiss, util
 
 
 def copy_scripts():
@@ -13,13 +13,13 @@ def copy_scripts():
     # Find efs pod
     pods = settings.k8s.find_pod(namespace="default", keyword="test-efs")
     if not pods:
-        return hiss.hiss('cannot find tiller pod')
+        return hiss.hiss('cannot find EFS pod')
 
     # Check empty folder
     exec_command = [
         '/bin/bash',
         '-c',
-        'test -d %s && echo "1" || echo "0"'  % (settings.EFS_ROOT)]
+        'test -d %s/akc-ca-data && echo "1" || echo "0"'  % (settings.EFS_ROOT)]
 
     result_get_folder = settings.k8s.exec_pod(
         podName=pods[0], namespace="default", command=exec_command)
@@ -28,7 +28,7 @@ def copy_scripts():
         exec_command = [
             '/bin/bash',
             '-c',
-            'mkdir -p %s/admin; mkdir -p %s/akc-ca-data' % (settings.EFS_ROOT, settings.EFS_ROOT)]
+            'mkdir -p %s/admin-v2/artifacts; mkdir -p %s/akc-ca-data' % (settings.EFS_ROOT, settings.EFS_ROOT)]
 
         # Create folder in efs
         result_create_folder = settings.k8s.exec_pod(
@@ -39,7 +39,7 @@ def copy_scripts():
     # Copy config to scripts/env
     hiss.sub_echo('Copy config to scripts/env')
     config_file = expanduser('~/.akachain/akc-mamba/mamba/config/.env')
-    env_script_File = expanduser('~/.akachain/akc-mamba/mamba/blockchain/scripts/env-scripts.sh')
+    env_script_File = expanduser('~/.akachain/akc-mamba/mamba/scripts/env-scripts.sh')
     copyfile(config_file, env_script_File)
 
     # Remove old script folder in efs
@@ -56,7 +56,7 @@ def copy_scripts():
 
     # Copy scripts folder to efs
     hiss.sub_echo('Copy scripts folder to efs')
-    script_path = expanduser('~/.akachain/akc-mamba/mamba/blockchain/scripts')
+    script_path = expanduser('~/.akachain/akc-mamba/mamba/scripts')
     if not settings.k8s.cp_to_pod(podName=pods[0], namespace='default', source=script_path, target='%s/akc-ca-scripts' % settings.EFS_ROOT):
         return hiss.hiss('connot copy scripts folder to pod %s' % pods[0])
 
@@ -73,8 +73,8 @@ def copy_scripts():
 
     # Copy test chaincode to efs
     hiss.sub_echo('Copy test chaincode to efs')
-    artifacts_path = expanduser('~/.akachain/akc-mamba/mamba/blockchain/artifacts')
-    if not settings.k8s.cp_to_pod(podName=pods[0], namespace='default', source=artifacts_path, target='%s/admin/artifacts' % settings.EFS_ROOT):
+    artifacts_path = util.get_package_resource('blockchain', 'artifacts/src/chaincodes')
+    if not settings.k8s.cp_to_pod(podName=pods[0], namespace='default', source=artifacts_path, target='%s/admin-v2/chaincodes' % settings.EFS_ROOT):
         return hiss.hiss('connot copy test chaincode to pod %s' % pods[0])
 
     return True
