@@ -23,8 +23,11 @@ from blockchain.orderer.commands import setup_all_orderer
 from blockchain.peer.commands import setup_all_peer
 from blockchain.gen_artifact.commands import generate_artifact
 from k8s.secret.commands import create_all_docker_secret
-from blockchain.admin.commands import setup_admin
+from blockchain.admin.commands import setup_all_admin
 from blockchain.bootstrap_network.commands import bootstrap_network
+from blockchain.external_chaincode.commands import config_all_peer
+from blockchain.generate_ccp.commands import generate_all_ccp
+from blockchain.update_anchor_peer.commands import setup_all
 
 
 def start_network():
@@ -34,48 +37,50 @@ def start_network():
     copy_scripts()
 
     # Create a new Root Certificate Authority service
+    hiss.rattle('Create a new Root Certificate Authority service')
     setup_rca()
 
     # Create new Intermediate Certificate Authority services
+    hiss.rattle('Create new Intermediate Certificate Authority services')
     setup_all_ica()
 
     # Run jobs to register organizations
+    hiss.rattle('Run jobs to register organizations')
     reg_all_org()
 
     # Run jobs to register orderers
+    hiss.rattle('Run jobs to register orderers')
     reg_all_orderer()
 
     # Run jobs to register peers
+    hiss.rattle('Run jobs to register peers')
     reg_all_peer()
 
-    # Run jobs to enroll orderers
+    hiss.rattle('Run jobs to enroll orderers')
     enroll_all_orderer()
 
-    # Run jobs to enroll peers
+    hiss.rattle('Run jobs to enroll peers')
     enroll_all_peer()
 
     time.sleep(5)
 
-    # Create crypto-config folder to contains artifacts
-    update_folder()
-
-    if settings.ORDERER_TYPE == 'kafka':
-        # Create new Zookeeper services
-        setup_zookeeper()
-        # Create new Kafka services
-        setup_kafka()
-    
-    # Run job to generate channel.tx, genesis.block
+    hiss.rattle('Run job to generate channel.tx, genesis.block')
     gen_channel_artifact()
 
-    # Create new StatefullSet orderers
+    hiss.rattle('Config map for external chaincode')
+    config_all_peer()
+
+    #TODO: Auto generate cpp, builder config map and apply external builder config map
+
+    hiss.rattle('Create new StatefullSet orderers')
     setup_all_orderer()
 
-    # Create new StatefullSet peers
+    hiss.rattle('Create new StatefullSet peers')
     setup_all_peer()
 
-    # Run jobs to generate application artifacts
+    # # Run jobs to generate application artifacts
     generate_artifact()
+    generate_all_ccp()
 
     # Create secret if use private docker hub
     if settings.PRIVATE_DOCKER_IMAGE == 'true':
@@ -83,15 +88,18 @@ def start_network():
 
     # Create new a new Admin service
     time.sleep(1)
-    setup_admin()
+    setup_all_admin()
+    time.sleep(1)
 
     # Bootrap network
-    time.sleep(1)
     bootstrap_network()
 
-    # cat log
-    domains = settings.ORDERER_DOMAINS.split(' ')
-    settings.k8s.read_pod_log('bootstrap-network', domains[0])
+    # # Setup anchor peer
+    # setup_all()
+
+    # # cat log
+    # domains = settings.ORDERER_DOMAINS.split(' ')
+    # settings.k8s.read_pod_log('bootstrap-network', domains[0])
 
     return True
 
