@@ -26,9 +26,11 @@ def fetch_config(org=None, domain=None):
         'ORDERER_NAME': settings.ORDERER_ORGS,
         'ORDERER_DOMAIN': settings.ORDERER_DOMAINS,
         'CHANNEL_NAME': settings.CHANNEL_NAME,
+        'FABRIC_TAG': settings.FABRIC_TAG,
         'EFS_SERVER': settings.EFS_SERVER,
         'EFS_PATH': settings.EFS_PATH,
-        'EFS_EXTEND': settings.EFS_EXTEND
+        'EFS_EXTEND': settings.EFS_EXTEND,
+        'PVS_PATH': settings.PVS_PATH
     }
     k8s_template_file = '%s/add-org/2fetch-channel.yaml' % util.get_k8s_template_path()
     settings.k8s.apply_yaml_from_template(
@@ -41,9 +43,11 @@ def modify_config(domain=None):
     dict_env = {
         'ORG_DOMAIN': domain,
         'NEW_ORG_NAME': settings.NEW_ORG_NAME,
+        'FABRIC_TAG': settings.FABRIC_TAG,
         'EFS_SERVER': settings.EFS_SERVER,
         'EFS_PATH': settings.EFS_PATH,
-        'EFS_EXTEND': settings.EFS_EXTEND
+        'EFS_EXTEND': settings.EFS_EXTEND,
+        'PVS_PATH': settings.PVS_PATH
     }
     k8s_template_file = '%s/add-org/3modifyingorgmaterial.yaml' % util.get_k8s_template_path()
     settings.k8s.apply_yaml_from_template(
@@ -57,9 +61,11 @@ def create_config_update_pb(domain=None):
     dict_env = {
         'ORG_DOMAIN': domain,
         'CHANNEL_NAME': settings.CHANNEL_NAME,
+        'FABRIC_TAG': settings.FABRIC_TAG,
         'EFS_SERVER': settings.EFS_SERVER,
         'EFS_PATH': settings.EFS_PATH,
-        'EFS_EXTEND': settings.EFS_EXTEND
+        'EFS_EXTEND': settings.EFS_EXTEND,
+        'PVS_PATH': settings.PVS_PATH
     }
     k8s_template_file = '%s/add-org/4createconfigupdate.yaml' % util.get_k8s_template_path()
     settings.k8s.apply_yaml_from_template(
@@ -76,9 +82,11 @@ def update_channel_config(org=None, domain=None):
         'CHANNEL_NAME': settings.CHANNEL_NAME,
         'ORDERER_NAME': settings.ORDERER_ORGS,
         'ORDERER_DOMAIN': settings.ORDERER_DOMAINS,
+        'FABRIC_TAG': settings.FABRIC_TAG,
         'EFS_SERVER': settings.EFS_SERVER,
         'EFS_PATH': settings.EFS_PATH,
-        'EFS_EXTEND': settings.EFS_EXTEND
+        'EFS_EXTEND': settings.EFS_EXTEND,
+        'PVS_PATH': settings.PVS_PATH
     }
     k8s_template_file = '%s/add-org/6updatechannelconfig.yaml' % util.get_k8s_template_path()
     settings.k8s.apply_yaml_from_template(
